# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from voltha_protos import afrouter_pb2 as voltha__protos_dot_afrouter__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2


class ConfigurationStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.SetConnection = channel.unary_unary(
        '/afrouter.Configuration/SetConnection',
        request_serializer=voltha__protos_dot_afrouter__pb2.Conn.SerializeToString,
        response_deserializer=voltha__protos_dot_afrouter__pb2.Result.FromString,
        )
    self.SetAffinity = channel.unary_unary(
        '/afrouter.Configuration/SetAffinity',
        request_serializer=voltha__protos_dot_afrouter__pb2.Affinity.SerializeToString,
        response_deserializer=voltha__protos_dot_afrouter__pb2.Result.FromString,
        )
    self.GetGoroutineCount = channel.unary_unary(
        '/afrouter.Configuration/GetGoroutineCount',
        request_serializer=voltha__protos_dot_afrouter__pb2.Empty.SerializeToString,
        response_deserializer=voltha__protos_dot_afrouter__pb2.Count.FromString,
        )
    self.UpdateLogLevel = channel.unary_unary(
        '/afrouter.Configuration/UpdateLogLevel',
        request_serializer=voltha__protos_dot_common__pb2.Logging.SerializeToString,
        response_deserializer=voltha__protos_dot_afrouter__pb2.Empty.FromString,
        )
    self.GetLogLevels = channel.unary_unary(
        '/afrouter.Configuration/GetLogLevels',
        request_serializer=voltha__protos_dot_common__pb2.LoggingComponent.SerializeToString,
        response_deserializer=voltha__protos_dot_common__pb2.Loggings.FromString,
        )


class ConfigurationServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def SetConnection(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetAffinity(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetGoroutineCount(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateLogLevel(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetLogLevels(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ConfigurationServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'SetConnection': grpc.unary_unary_rpc_method_handler(
          servicer.SetConnection,
          request_deserializer=voltha__protos_dot_afrouter__pb2.Conn.FromString,
          response_serializer=voltha__protos_dot_afrouter__pb2.Result.SerializeToString,
      ),
      'SetAffinity': grpc.unary_unary_rpc_method_handler(
          servicer.SetAffinity,
          request_deserializer=voltha__protos_dot_afrouter__pb2.Affinity.FromString,
          response_serializer=voltha__protos_dot_afrouter__pb2.Result.SerializeToString,
      ),
      'GetGoroutineCount': grpc.unary_unary_rpc_method_handler(
          servicer.GetGoroutineCount,
          request_deserializer=voltha__protos_dot_afrouter__pb2.Empty.FromString,
          response_serializer=voltha__protos_dot_afrouter__pb2.Count.SerializeToString,
      ),
      'UpdateLogLevel': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateLogLevel,
          request_deserializer=voltha__protos_dot_common__pb2.Logging.FromString,
          response_serializer=voltha__protos_dot_afrouter__pb2.Empty.SerializeToString,
      ),
      'GetLogLevels': grpc.unary_unary_rpc_method_handler(
          servicer.GetLogLevels,
          request_deserializer=voltha__protos_dot_common__pb2.LoggingComponent.FromString,
          response_serializer=voltha__protos_dot_common__pb2.Loggings.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'afrouter.Configuration', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
